#!/bin/bash
#SBATCH --partition=public
#SBATCH --job-name=amberMPI
#SBATCH --nodes=2                # Numero de nodos: 2, 3, ...
#SBATCH --ntasks-per-node=30     # Numero de procesos: 2, 3,...30
#SBATCH --output slurm.%N.%j.out # STDOUT 
#SBATCH --error slurm.%N.%j.err  # STDERR

# cd to the directory where the job was submitted
cd $SLURM_SUBMIT_DIR

# Cargar modulo
module purge
module use /opt/apps/easybuild/modules/all
module load Amber/22

# Exportar variables
export OMPI_MCA_btl_openib_allow_ib=1
export OMPI_MCA_btl_openib_if_include="qib0:1"

# Run amber parallel
cat << eof > equil.in
!equil ras-raf
 &cntrl
  imin=0,irest=1,ntx=5,
  nstlim=250000,dt=0.002,
  ntc=2,ntf=2,
  cut=10.0, ntb=2, ntp=1, taup=2.0,
  ntpr=1000, ntwx=1000,
  ntt=3, gamma_ln=2.0,
  temp0=300.0,
  nmropt=0
  ntr  = 0,
 /
eof

mpirun -n $SLURM_NTASKS sander.MPI -O \
                                   -i equil.in \
                                   -o equil.out \
                                   -r equil.rst \
                                   -ref parm.crd \
                                   -x equil.cor \
                                   -e equil.ene \
                                   -inf equil.info \
                                   -c density.rst \
